@@ -912,7 +912,7 @@ class Channel(callbacks.Plugin):
         if 's' in irc.state.channels[channel].modes and \
             msg.args[0] != channel and \
             not ircdb.checkCapability(msg.prefix, capability) and \
-            (ircutils.isChannel(msg.args[0]) or \
+            (irc.isChannel(msg.args[0]) or \
              msg.nick not in irc.state.channels[channel].users):
             irc.error(_('You don\'t have access to that information.'),
                     Raise=True)
